cmoncrawl.processor.pipeline.streamer.BaseStreamerFile.\_\_init\_\_
===================================================================

.. currentmodule:: cmoncrawl.processor.pipeline.streamer

.. automethod:: BaseStreamerFile.__init__